========================
cubicweb.timeline-ext.js
========================
.. module:: cubicweb.timeline-ext.js

:organization: Logilab
 :copyright: 2008-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr

provide our own custom date parser since the default
one only understands iso8601 and gregorian dates

CUBICWEB EVENT PAINTER ****************************************************